
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.29.0',
    'branch_nick': 'master',
    'revision_id': '0aec3e514c649de3c4d8068a35c05ab2280d59eb',
    'revno': 11848
}
